@@ -56,12 +56,12 @@ sub xsub_def {
 
     # Iterate over args in param list.
     for ( my $i = 1; $i <= $#$arg_vars; $i++ ) {
-        my $var        = $arg_vars->[$i];
-        my $val        = $arg_inits->[$i];
-        my $name       = $var->micro_sym;
-        my $sv_name    = $name . "_sv";
-        my $type       = $var->get_type;
-        my $len        = length $name;
+        my $var     = $arg_vars->[$i];
+        my $val     = $arg_inits->[$i];
+        my $name    = $var->micro_sym;
+        my $sv_name = $name . "_sv";
+        my $type    = $var->get_type;
+        my $len     = length $name;
 
         # Create snippet for extracting sv from stack, if supplied.
         $allot_params .= qq|            &$sv_name, "$name", $len,\n|;
@@ -106,16 +106,14 @@ sub xsub_def {
     my $refcount_mods = join( "\n        ", @refcount_mods );
 
     return <<END_STUFF;
-XS($c_name); /* -Wmissing-prototypes */
+XS($c_name);
 XS($c_name)
 {
     dXSARGS;
     CHY_UNUSED_VAR(cv);
     CHY_UNUSED_VAR(ax);
-    if (items < 1)
-        THROW(KINO_ERR, "Usage: %s(class_name, ...)",  GvNAME(CvGV(cv)));
+    if (items < 1) { THROW(KINO_ERR, "Usage: %s(class_name, ...)",  GvNAME(CvGV(cv))); }
     SP -= items;
-
     {
         $var_declarations
         $var_assignments
@@ -131,7 +129,6 @@ XS($c_name)
         sv_2mortal( ST(0) );
         XSRETURN(1);
     }
-
     PUTBACK;
 }
 
@@ -189,4 +186,3 @@ This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 =cut
-
