@@ -15,7 +15,7 @@
 
 LexiconReader*
 LexReader_init(LexiconReader *self, Schema *schema, Folder *folder,
-               Snapshot *snapshot, VArray *segments, i32_t seg_tick)
+               Snapshot *snapshot, VArray *segments, int32_t seg_tick)
 {
     DataReader_init((DataReader*)self, schema, folder, snapshot, segments,
         seg_tick);
@@ -42,7 +42,7 @@ PolyLexiconReader*
 PolyLexReader_init(PolyLexiconReader *self, VArray *readers, 
                    I32Array *offsets)
 {
-    u32_t i, max;
+    uint32_t i, max;
     Schema *schema = NULL;
     for (i = 0, max = VA_Get_Size(readers); i < max; i++) {
         LexiconReader *reader = (LexiconReader*)CERTIFY(
@@ -59,7 +59,7 @@ void
 PolyLexReader_close(PolyLexiconReader *self)
 {
     if (self->readers) {
-        u32_t i, max;
+        uint32_t i, max;
         for (i = 0, max = VA_Get_Size(self->readers); i < max; i++) {
             LexiconReader *reader 
                 = (LexiconReader*)VA_Fetch(self->readers, i);
@@ -99,12 +99,12 @@ PolyLexReader_lexicon(PolyLexiconReader *self, const CharBuf *field,
     return (Lexicon*)lexicon;
 }
 
-u32_t
+uint32_t
 PolyLexReader_doc_freq(PolyLexiconReader *self, const CharBuf *field,
                        Obj *term)
 {
-    u32_t doc_freq = 0;
-    u32_t i, max;
+    uint32_t doc_freq = 0;
+    uint32_t i, max;
     for (i = 0, max = VA_Get_Size(self->readers); i < max; i++) {
         LexiconReader *reader = (LexiconReader*)VA_Fetch(self->readers, i);
         if (reader) {
@@ -116,7 +116,7 @@ PolyLexReader_doc_freq(PolyLexiconReader *self, const CharBuf *field,
 
 DefaultLexiconReader*
 DefLexReader_new(Schema *schema, Folder *folder, Snapshot *snapshot,
-                 VArray *segments, i32_t seg_tick)
+                 VArray *segments, int32_t seg_tick)
 {
     DefaultLexiconReader *self 
         = (DefaultLexiconReader*)VTable_Make_Obj(DEFAULTLEXICONREADER);
@@ -124,22 +124,21 @@ DefLexReader_new(Schema *schema, Folder *folder, Snapshot *snapshot,
         seg_tick);
 }
 
-/* Indicate whether it is safe to build a SegLexicon using the given
- * parameters. Will return false if the field is not indexed or if no terms
- * are present for this field in this segment.
- */
+// Indicate whether it is safe to build a SegLexicon using the given
+// parameters. Will return false if the field is not indexed or if no terms
+// are present for this field in this segment.
 static bool_t
 S_has_data(Schema *schema, Folder *folder, Segment *segment, CharBuf *field)
 {
     FieldType *type = Schema_Fetch_Type(schema, field);
 
     if ( !type || !FType_Indexed(type)) {
-        /* If the field isn't indexed, bail out. */
+        // If the field isn't indexed, bail out. 
         return false;
     }
     else {
-        /* Bail out if there are no terms for this field in this segment. */
-        i32_t field_num   = Seg_Field_Num(segment, field);
+        // Bail out if there are no terms for this field in this segment. 
+        int32_t field_num   = Seg_Field_Num(segment, field);
         CharBuf *seg_name = Seg_Get_Name(segment);
         CharBuf *file = CB_newf("%o/lexicon-%i32.dat", seg_name, field_num);
         bool_t retval = Folder_Exists(folder, file);
@@ -150,17 +149,17 @@ S_has_data(Schema *schema, Folder *folder, Segment *segment, CharBuf *field)
 
 DefaultLexiconReader*
 DefLexReader_init(DefaultLexiconReader *self, Schema *schema, Folder *folder,
-               Snapshot *snapshot, VArray *segments, i32_t seg_tick)
+               Snapshot *snapshot, VArray *segments, int32_t seg_tick)
 {
     Segment *segment;
-    u32_t    i, max;
+    uint32_t i, max;
 
-    /* Init. */
+    // Init. 
     LexReader_init((LexiconReader*)self, schema, folder, snapshot, segments,
         seg_tick);
     segment = DefLexReader_Get_Segment(self);
 
-    /* Build an array of SegLexicon objects. */
+    // Build an array of SegLexicon objects. 
     self->lexicons = VA_new(Schema_Num_Fields(schema));
     for (i = 1, max = Schema_Num_Fields(schema) + 1; i < max; i++) {
         CharBuf *field = Seg_Field_Name(segment, i);
@@ -191,11 +190,11 @@ Lexicon*
 DefLexReader_lexicon(DefaultLexiconReader *self, const CharBuf *field, 
                      Obj *term)
 {
-    i32_t       field_num = Seg_Field_Num(self->segment, field);
+    int32_t     field_num = Seg_Field_Num(self->segment, field);
     SegLexicon *orig      = (SegLexicon*)VA_Fetch(self->lexicons, field_num);
     SegLexicon *lexicon   = NULL;
 
-    if (orig) { /* i.e. has data */
+    if (orig) { // i.e. has data 
         lexicon 
             = SegLex_new(self->schema, self->folder, self->segment, field);
         SegLex_Seek(lexicon, term);
@@ -208,15 +207,15 @@ static TermInfo*
 S_find_tinfo(DefaultLexiconReader *self, const CharBuf *field, Obj *target)
 {    
     if (field != NULL && target != NULL) {
-        i32_t field_num = Seg_Field_Num(self->segment, field);
+        int32_t field_num = Seg_Field_Num(self->segment, field);
         SegLexicon *lexicon 
             = (SegLexicon*)VA_Fetch(self->lexicons, field_num);
 
         if (lexicon) {
-            /* Iterate until the result is ge the term. */ 
+            // Iterate until the result is ge the term.  
             SegLex_Seek(lexicon, target);
 
-            /*if found matches target, return info; otherwise NULL */
+            //if found matches target, return info; otherwise NULL 
             {
                 Obj *found = SegLex_Get_Term(lexicon);
                 if (found && Obj_Equals(target, found)) {
@@ -236,7 +235,7 @@ DefLexReader_fetch_term_info(DefaultLexiconReader *self,
     return tinfo ? TInfo_Clone(tinfo) : NULL;
 }
 
-u32_t
+uint32_t
 DefLexReader_doc_freq(DefaultLexiconReader *self, const CharBuf *field,
                       Obj *term)
 {
