@@ -9,7 +9,6 @@
 #include "KinoSearch/Search/QueryParser.h"
 #include "KinoSearch/Analysis/Analyzer.h"
 #include "KinoSearch/Plan/FieldType.h"
-#include "KinoSearch/Plan/FullTextType.h"
 #include "KinoSearch/Plan/Schema.h"
 #include "KinoSearch/Search/LeafQuery.h"
 #include "KinoSearch/Search/ANDQuery.h"
@@ -35,62 +34,57 @@
 #define TOKEN_FIELD       0x00000400
 #define TOKEN_QUERY       0x00000800
 
-/* Recursing helper function for Tree(). */
+// Recursing helper function for Tree(). 
 static Query*
 S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field, 
           Hash *extractions);
 
-/* A function that attempts to match a substring and if successful, stores the
- * begin and end of the match in the supplied pointers and returns true.
- */
+// A function that attempts to match a substring and if successful, stores the
+// begin and end of the match in the supplied pointers and returns true.
 typedef bool_t
 (*kino_QueryParser_match_t)(CharBuf *input, char **begin_match, 
                             char **end_match);
 #define match_t kino_QueryParser_match_t
 
-/* Find a quote/end-of-string -delimited phrase.
- */
+// Find a quote/end-of-string -delimited phrase.
 static bool_t
 S_match_phrase(CharBuf *input, char**begin_match, char **end_match);
 
-/* Find a non-nested parethetical group.
- */
+// Find a non-nested parethetical group.
 static bool_t
 S_match_bool_group(CharBuf *input, char**begin_match, char **end_match);
 
-/* Replace whatever match() matches with a label, storing the matched text as
- * a CharBuf in the supplied storage Hash.
- */
+// Replace whatever match() matches with a label, storing the matched text as
+// a CharBuf in the supplied storage Hash.
 static CharBuf*
 S_extract_something(QueryParser *self, const CharBuf *query_string, 
                     CharBuf *label, Hash *extractions, match_t match);
 
-/* Symbolically replace phrases in a query string. */
+// Symbolically replace phrases in a query string. 
 static CharBuf*
 S_extract_phrases(QueryParser *self, const CharBuf *query_string, 
                   Hash *extractions);
 
-/* Symbolically replace parenthetical groupings in a query string. */
+// Symbolically replace parenthetical groupings in a query string. 
 static CharBuf*
 S_extract_paren_groups(QueryParser *self, const CharBuf *query_string, 
                        Hash *extractions);
 
-/* Consume text and possibly following whitespace, if there's a match and the
- * matching is bordered on the right by either whitespace or the end of the
- * string.
- */
+// Consume text and possibly following whitespace, if there's a match and the
+// matching is bordered on the right by either whitespace or the end of the
+// string.
 static bool_t
 S_consume_ascii_token(ViewCharBuf *qstring, char *ptr, size_t size);
 
-/* Consume the supplied text if there's a match.  */
+// Consume the supplied text if there's a match.  
 static bool_t
 S_consume_ascii(ViewCharBuf *qstring, char *ptr, size_t size);
 
-/* Consume what looks like a field name followed by a colon.  */
+// Consume what looks like a field name followed by a colon.  
 static bool_t
 S_consume_field(ViewCharBuf *qstring, ViewCharBuf *target);
 
-/* Consume non-whitespace from qstring and store the match in target. */
+// Consume non-whitespace from qstring and store the match in target. 
 static bool_t
 S_consume_non_whitespace(ViewCharBuf *qstring, ViewCharBuf *target);
 
@@ -110,13 +104,13 @@ QueryParser*
 QParser_init(QueryParser *self, Schema *schema, Analyzer *analyzer,
              const CharBuf *default_boolop, VArray *fields)
 {
-    u32_t i;
+    uint32_t i;
 
-    /* Init. */
+    // Init. 
     self->heed_colons = false;
     self->label_inc   = 0;
 
-    /* Assign. */
+    // Assign. 
     self->schema         = (Schema*)INCREF(schema);
     self->analyzer       = (Analyzer*)INCREF(analyzer);
     self->default_boolop = default_boolop
@@ -124,19 +118,17 @@ QParser_init(QueryParser *self, Schema *schema, Analyzer *analyzer,
                          : CB_new_from_trusted_utf8("OR", 2);
     
     if (fields) {
-        u32_t i, max;
         self->fields = VA_Shallow_Copy(fields);
-        for (i = 0, max = VA_Get_Size(fields); i < max; i++) {
+        for (uint32_t i = 0, max = VA_Get_Size(fields); i < max; i++) {
             CERTIFY(VA_Fetch(fields, i), CHARBUF);
         }
         VA_Sort(self->fields, NULL, NULL);
     }
     else {
-        u32_t i;
         VArray *all_fields = Schema_All_Fields(schema);
-        u32_t num_fields = VA_Get_Size(all_fields);
+        uint32_t num_fields = VA_Get_Size(all_fields);
         self->fields = VA_new(num_fields);
-        for (i = 0; i < num_fields; i++) {
+        for (uint32_t i = 0; i < num_fields; i++) {
             CharBuf *field = (CharBuf*)VA_Fetch(all_fields, i);
             FieldType *type = Schema_Fetch_Type(schema, field);
             if (type && FType_Indexed(type)) {
@@ -153,7 +145,7 @@ QParser_init(QueryParser *self, Schema *schema, Analyzer *analyzer,
         THROW(ERR, "Invalid value for default_boolop: %o", self->default_boolop);
     }
 
-    /* Create string labels that presumably won't appear in a search. */
+    // Create string labels that presumably won't appear in a search. 
     self->phrase_label     = CB_new_from_trusted_utf8("_phrase", 7);
     self->bool_group_label = CB_new_from_trusted_utf8("_bool_group", 11);
     CB_Grow(self->phrase_label, PHRASE_LABEL_LEN + 5);
@@ -245,7 +237,7 @@ S_parse_flat_string(QueryParser *self, CharBuf *query_string)
         ParserToken *token = NULL;
 
         if (ViewCB_Trim_Top(qstring)) { 
-            /* Fast-forward past whitespace. */
+            // Fast-forward past whitespace. 
             continue;
         }
         else if (S_consume_ascii(qstring, "+", 1)) {
@@ -283,20 +275,19 @@ S_parse_flat_string(QueryParser *self, CharBuf *query_string)
             (Obj*)ParserToken_new(TOKEN_CLOSE_PAREN, NULL, 0));
     }
 
-    /* Clean up. */
+    // Clean up. 
     DECREF(qstring_copy);
 
     return parse_tree;
 }
 
 static void
-S_splice_out_token_type(VArray *elems, u32_t token_type_mask)
+S_splice_out_token_type(VArray *elems, uint32_t token_type_mask)
 {
-    u32_t i;
-    for (i = VA_Get_Size(elems); i--; ) {
+    for (uint32_t i = VA_Get_Size(elems); i--; ) {
         ParserToken *token = (ParserToken*)VA_Fetch(elems, i);
         if (Obj_Is_A((Obj*)token, PARSERTOKEN)) {
-            if (token->type & token_type_mask) VA_Splice(elems, i, 1);
+            if (token->type & token_type_mask) VA_Excise(elems, i, 1);
         }
     }
 }
@@ -305,42 +296,42 @@ static Query*
 S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field, 
           Hash *extractions)
 {
-    Query  *retval;
-    bool_t  apply_parens   = false;
-    u32_t   default_occur  = CB_Equals_Str(self->default_boolop, "AND", 3)
-                           ? MUST
-                           : SHOULD;
-    VArray *elems          = S_parse_flat_string(self, query_string);
-    u32_t   i, max;
+    Query    *retval;
+    bool_t    apply_parens  = false;
+    uint32_t  default_occur = CB_Equals_Str(self->default_boolop, "AND", 3)
+                            ? MUST
+                            : SHOULD;
+    VArray *elems           = S_parse_flat_string(self, query_string);
+    uint32_t i, max;
     
-    /* Determine whether this subclause is bracketed by parens. */
+    // Determine whether this subclause is bracketed by parens. 
     {
         ParserToken *maybe_open_paren = (ParserToken*)VA_Fetch(elems, 0);
         if (   maybe_open_paren != NULL 
             && maybe_open_paren->type == TOKEN_OPEN_PAREN
         ) {
-            u32_t num_elems;
+            uint32_t num_elems;
             apply_parens = true;
-            VA_Splice(elems, 0, 1);
+            VA_Excise(elems, 0, 1);
             num_elems = VA_Get_Size(elems);
             if (num_elems) {
                 ParserToken *maybe_close_paren 
                     = (ParserToken*)VA_Fetch(elems, num_elems - 1);
                 if (maybe_close_paren->type == TOKEN_CLOSE_PAREN) {
-                    VA_Splice(elems, num_elems - 1, 1);
+                    VA_Excise(elems, num_elems - 1, 1);
                 }
             }
         }
     }
 
-    /* Generate all queries.  Apply any fields. */
+    // Generate all queries.  Apply any fields. 
     for (i = VA_Get_Size(elems); i--; ) {
         CharBuf *field = default_field;
         ParserToken *token = (ParserToken*)VA_Fetch(elems, i);
 
-        /* Apply field. */
+        // Apply field. 
         if (i > 0) {
-            /* Field specifier must immediately precede any query. */
+            // Field specifier must immediately precede any query. 
             ParserToken* maybe_field_token
                 = (ParserToken*)VA_Fetch(elems, i - 1);
             if (maybe_field_token->type == TOKEN_FIELD) {
@@ -349,7 +340,7 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
         }
 
         if (token->type == TOKEN_QUERY) {
-            /* Generate a LeafQuery from a Phrase. */
+            // Generate a LeafQuery from a Phrase. 
             if (CB_Starts_With(token->text, self->phrase_label)) {
                 CharBuf *inner_text 
                     = (CharBuf*)Hash_Fetch(extractions, (Obj*)token->text);
@@ -359,7 +350,7 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
                 VA_Store(elems, i, (Obj*)clause);
                 DECREF(query);
             }
-            /* Recursively parse parenthetical groupings. */
+            // Recursively parse parenthetical groupings. 
             else if (CB_Starts_With(token->text, self->bool_group_label)) {
                 CharBuf *inner_text 
                     = (CharBuf*)Hash_Fetch(extractions, (Obj*)token->text);
@@ -373,7 +364,7 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
                     DECREF(query);
                 }
             }
-            /* What's left is probably a term, so generate a LeafQuery. */
+            // What's left is probably a term, so generate a LeafQuery. 
             else {
                 Query *query = (Query*)LeafQuery_new(field, token->text);
                 ParserClause *clause = ParserClause_new(query, default_occur);
@@ -384,11 +375,11 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
     }
     S_splice_out_token_type(elems, TOKEN_FIELD | TOKEN_QUERY);
 
-    /* Apply +, -, NOT. */
+    // Apply +, -, NOT. 
     for (i = VA_Get_Size(elems); i--; ) {
         ParserClause *clause = (ParserClause*)VA_Fetch(elems, i);
         if (Obj_Is_A((Obj*)clause, PARSERCLAUSE)) {
-            u32_t j;
+            uint32_t j;
             for (j = i; j--; ) {
                 ParserToken *token = (ParserToken*)VA_Fetch(elems, j);
                 if (Obj_Is_A((Obj*)token, PARSERTOKEN)) {
@@ -413,7 +404,7 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
     }
     S_splice_out_token_type(elems, TOKEN_PLUS | TOKEN_MINUS | TOKEN_NOT);
 
-    /* Wrap negated queries with NOTQuery objects. */
+    // Wrap negated queries with NOTQuery objects. 
     for (i = 0, max = VA_Get_Size(elems); i < max; i++) {
         ParserClause *clause = (ParserClause*)VA_Fetch(elems, i);
         if (Obj_Is_A((Obj*)clause, PARSERCLAUSE) && clause->occur == MUST_NOT) {
@@ -423,13 +414,13 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
         }
     }
 
-    /* Silently discard non-sensical combos of AND and OR, e.g. 
-     * 'OR a AND AND OR b AND'. */
-    for (i = 0, max = VA_Get_Size(elems); i < max; i++) {
+    // Silently discard non-sensical combos of AND and OR, e.g. 
+    // 'OR a AND AND OR b AND'.
+    for (i = 0; i < VA_Get_Size(elems); i++) {
         ParserToken *token = (ParserToken*)VA_Fetch(elems, i);
         if (Obj_Is_A((Obj*)token, PARSERTOKEN)) {
-            u32_t j, jmax;
-            u32_t num_to_zap = 0;
+            uint32_t j, jmax;
+            uint32_t num_to_zap = 0;
             ParserClause *preceding = (ParserClause*)VA_Fetch(elems, i - 1);
             ParserClause *following = (ParserClause*)VA_Fetch(elems, i + 1);
             if (!preceding || !Obj_Is_A((Obj*)preceding, PARSERCLAUSE)) {
@@ -443,23 +434,23 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
                 if (Obj_Is_A((Obj*)clause, PARSERCLAUSE)) break;
                 else num_to_zap++;
             }
-            if (num_to_zap) VA_Splice(elems, i, num_to_zap);
+            if (num_to_zap) VA_Excise(elems, i, num_to_zap);
         }
     }
 
-    /* Apply AND. */
+    // Apply AND. 
     for (i = 0; i + 2 < VA_Get_Size(elems); i++) {
         ParserToken *token = (ParserToken*)VA_Fetch(elems, i + 1);
         if (Obj_Is_A((Obj*)token, PARSERTOKEN) && token->type == TOKEN_AND) {
             ParserClause *preceding  = (ParserClause*)VA_Fetch(elems, i);
             VArray       *children   = VA_new(2);
-            u32_t         num_to_zap = 0;
-            u32_t         j, jmax;
+            uint32_t      num_to_zap = 0;
+            uint32_t      j, jmax;
 
-            /* Add first clause. */
+            // Add first clause. 
             VA_Push(children, INCREF(preceding->query));
 
-            /* Add following clauses.  */
+            // Add following clauses.  
             for (j = i + 1, jmax = VA_Get_Size(elems); 
                  j < jmax; 
                  j += 2, num_to_zap+= 2
@@ -482,26 +473,26 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
             preceding->occur = default_occur;
             DECREF(children);
 
-            VA_Splice(elems, i + 1, num_to_zap);
+            VA_Excise(elems, i + 1, num_to_zap);
 
-            /* Don't double wrap '(a AND b)'. */
+            // Don't double wrap '(a AND b)'. 
             if (VA_Get_Size(elems) == 1) apply_parens = false;
         }
     }
 
-    /* Apply OR. */
+    // Apply OR. 
     for (i = 0; i + 2 < VA_Get_Size(elems); i++) {
         ParserToken *token = (ParserToken*)VA_Fetch(elems, i + 1);
         if (Obj_Is_A((Obj*)token, PARSERTOKEN) && token->type == TOKEN_OR) {
             ParserClause *preceding  = (ParserClause*)VA_Fetch(elems, i);
             VArray       *children   = VA_new(2);
-            u32_t         num_to_zap = 0;
-            u32_t         j, jmax;
+            uint32_t      num_to_zap = 0;
+            uint32_t      j, jmax;
 
-            /* Add first clause. */
+            // Add first clause. 
             VA_Push(children, INCREF(preceding->query));
 
-            /* Add following clauses.  */
+            // Add following clauses.  
             for (j = i + 1, jmax = VA_Get_Size(elems); 
                  j < jmax; 
                  j += 2, num_to_zap+= 2
@@ -524,16 +515,16 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
             preceding->occur = default_occur;
             DECREF(children);
 
-            VA_Splice(elems, i + 1, num_to_zap);
+            VA_Excise(elems, i + 1, num_to_zap);
 
-            /* Don't double wrap '(a OR b)'. */
+            // Don't double wrap '(a OR b)'. 
             if (VA_Get_Size(elems) == 1) apply_parens = false;
         }
     }
 
     if (VA_Get_Size(elems) == 0) {
-        /* No elems means no query. Maybe the search string was something
-         * like 'NOT AND' */
+        // No elems means no query. Maybe the search string was something
+        // like 'NOT AND' 
         if (apply_parens) {
             retval = default_occur == SHOULD 
                    ? QParser_Make_OR_Query(self, NULL)
@@ -548,15 +539,15 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
         retval = (Query*)INCREF(clause->query);
     }
     else {
-        u32_t num_elems = VA_Get_Size(elems);
-        VArray *required  = VA_new(num_elems);
-        VArray *optional  = VA_new(num_elems);
-        VArray *negated   = VA_new(num_elems);
-        Query  *req_query = NULL;
-        Query  *opt_query = NULL;
-        u32_t   i, num_required, num_negated, num_optional;
+        uint32_t  num_elems = VA_Get_Size(elems);
+        VArray   *required  = VA_new(num_elems);
+        VArray   *optional  = VA_new(num_elems);
+        VArray   *negated   = VA_new(num_elems);
+        Query    *req_query = NULL;
+        Query    *opt_query = NULL;
+        uint32_t  i, num_required, num_negated, num_optional;
 
-        /* Demux elems into bins. */
+        // Demux elems into bins. 
         for (i = 0; i < num_elems; i++) {
             ParserClause *clause = (ParserClause*)VA_Fetch(elems, i);
             if (clause->occur == MUST) 
@@ -570,7 +561,7 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
         num_negated  = VA_Get_Size(negated);
         num_optional = VA_Get_Size(optional);
 
-        /* Bind all mandatory matchers together in one Query. */
+        // Bind all mandatory matchers together in one Query. 
         if (num_required || num_negated) {
             if (apply_parens || num_required + num_negated > 1) {
                 VArray *children = VA_Shallow_Copy(required);
@@ -586,7 +577,7 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
             }
         }
         
-        /* Bind all optional matchers together in one Query. */
+        // Bind all optional matchers together in one Query. 
         if (num_optional) {
             if (!apply_parens && num_optional == 1) {
                 opt_query = (Query*)INCREF(VA_Fetch(optional, 0));
@@ -596,14 +587,14 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
             }
         }
 
-        /* Unify required and optional. */
+        // Unify required and optional. 
         if (req_query && opt_query) {
-            if (num_required) { /* not just negated elems */
+            if (num_required) { // not just negated elems 
                 retval = QParser_Make_Req_Opt_Query(self, req_query, 
                     opt_query);
             }
             else {
-                /* req_query has only negated queries. */
+                // req_query has only negated queries. 
                 VArray *children = VA_new(2);
                 VA_Push(children, INCREF(req_query));
                 VA_Push(children, INCREF(opt_query));
@@ -612,15 +603,15 @@ S_do_tree(QueryParser *self, CharBuf *query_string, CharBuf *default_field,
             }
         }
         else if (opt_query) {
-            /* Only optional elems. */
+            // Only optional elems. 
             retval = (Query*)INCREF(opt_query);
         }
         else if (req_query) {
-            /* Only required elems. */
+            // Only required elems. 
             retval = (Query*)INCREF(req_query);
         }
         else {
-            retval = NULL; /* kill "uninitialized" compiler warning */
+            retval = NULL; // kill "uninitialized" compiler warning 
             THROW(ERR, "Unexpected error");
         }
 
@@ -644,8 +635,7 @@ S_has_valid_clauses(Query *query)
     else if (Query_Is_A(query, ORQUERY) || Query_Is_A(query, ANDQUERY)) {
         PolyQuery *polyquery = (PolyQuery*)query;
         VArray    *children  = PolyQuery_Get_Children(polyquery);
-        u32_t i, max;
-        for (i = 0, max = VA_Get_Size(children); i < max; i++) {
+        for (uint32_t i = 0, max = VA_Get_Size(children); i < max; i++) {
             Query *child = (Query*)VA_Fetch(children, i);
             if (S_has_valid_clauses(child)) return true;
         }
@@ -658,7 +648,7 @@ static void
 S_do_prune(QueryParser *self, Query *query)
 {
     if (Query_Is_A(query, NOTQUERY)) {
-        /* Don't allow double negatives. */
+        // Don't allow double negatives. 
         NOTQuery *not_query = (NOTQuery*)query;
         Query *neg_query = NOTQuery_Get_Negated_Query(not_query);
         if (   !Query_Is_A(neg_query, MATCHALLQUERY) 
@@ -672,10 +662,9 @@ S_do_prune(QueryParser *self, Query *query)
     else if (Query_Is_A(query, POLYQUERY)) {
         PolyQuery *polyquery = (PolyQuery*)query;
         VArray    *children  = PolyQuery_Get_Children(polyquery);
-        u32_t i, max;
 
-        /* Recurse. */
-        for (i = 0, max = VA_Get_Size(children); i < max; i++) {
+        // Recurse. 
+        for (uint32_t i = 0, max = VA_Get_Size(children); i < max; i++) {
             Query *child = (Query*)VA_Fetch(children, i);
             S_do_prune(self, child);
         }
@@ -683,9 +672,9 @@ S_do_prune(QueryParser *self, Query *query)
         if (   PolyQuery_Is_A(polyquery, REQUIREDOPTIONALQUERY)
             || PolyQuery_Is_A(polyquery, ORQUERY)
         ) {
-            /* Don't allow 'foo OR (-bar)'. */
+            // Don't allow 'foo OR (-bar)'. 
             VArray *children = PolyQuery_Get_Children(polyquery);
-            for (i = 0, max = VA_Get_Size(children); i < max; i++) {
+            for (uint32_t i = 0, max = VA_Get_Size(children); i < max; i++) {
                 Query *child = (Query*)VA_Fetch(children, i);
                 if (!S_has_valid_clauses(child)) {
                     VA_Store(children, i, (Obj*)NoMatchQuery_new());
@@ -693,7 +682,7 @@ S_do_prune(QueryParser *self, Query *query)
             }
         }
         else if (PolyQuery_Is_A(polyquery, ANDQUERY)) {
-            /* Don't allow '(-bar AND -baz)'. */
+            // Don't allow '(-bar AND -baz)'. 
             if (!S_has_valid_clauses((Query*)polyquery)) {
                 VArray *children = PolyQuery_Get_Children(polyquery);
                 VA_Clear(children);
@@ -748,13 +737,13 @@ S_consume_field(ViewCharBuf *qstring, ViewCharBuf *target)
     size_t tick = 0;
 
     while (1) {
-        u32_t code_point = ViewCB_Code_Point_At(qstring, tick);
+        uint32_t code_point = ViewCB_Code_Point_At(qstring, tick);
         if (isalnum(code_point) || code_point == '_') tick++;
         else if (code_point == ':') { tick++; break; }
         else return false;
     }
 
-    if (tick == 1) { /* just the colon */
+    if (tick == 1) { // just the colon 
         return false; 
     }
     else {
@@ -773,7 +762,7 @@ S_consume_field(ViewCharBuf *qstring, ViewCharBuf *target)
 static bool_t
 S_consume_non_whitespace(ViewCharBuf *qstring, ViewCharBuf *target)
 {
-    u32_t code_point = ViewCB_Code_Point_At(qstring, 0);
+    uint32_t code_point = ViewCB_Code_Point_At(qstring, 0);
     bool_t success = false;
     ViewCB_Assign(target, (CharBuf*)qstring);
     while (code_point && !StrHelp_is_whitespace(code_point)) {
@@ -785,7 +774,7 @@ S_consume_non_whitespace(ViewCharBuf *qstring, ViewCharBuf *target)
         return false;
     }
     else {
-        u32_t new_size = ViewCB_Get_Size(target) - ViewCB_Get_Size(qstring);
+        uint32_t new_size = ViewCB_Get_Size(target) - ViewCB_Get_Size(qstring);
         ViewCB_Set_Size(target, new_size);
         return true;
     }
@@ -803,11 +792,10 @@ QParser_expand(QueryParser *self, Query *query)
         PolyQuery *polyquery = (PolyQuery*)query;
         VArray *children = PolyQuery_Get_Children(polyquery);
         VArray *new_kids = VA_new(VA_Get_Size(children));
-        u32_t i, max;
 
-        for (i = 0, max = VA_Get_Size(children); i < max; i++) {
+        for (uint32_t i = 0, max = VA_Get_Size(children); i < max; i++) {
             Query *child = (Query*)VA_Fetch(children, i);
-            Query *new_child = QParser_Expand(self, child); /* recurse */
+            Query *new_child = QParser_Expand(self, child); // recurse 
             if (new_child) VA_Push(new_kids, (Obj*)new_child);
         }
         
@@ -868,20 +856,19 @@ static CharBuf*
 S_unescape(QueryParser *self, CharBuf *orig, CharBuf *target)
 {
     ZombieCharBuf *source = ZCB_WRAP(orig);
-    u32_t code_point;
-
-    if (!self->heed_colons) {
-        CB_Mimic(target, (Obj*)orig);
-        return target;
-    }
+    uint32_t code_point;
+    UNUSED_VAR(self);
 
     CB_Set_Size(target, 0);
     CB_Grow(target, CB_Get_Size(orig) + 4);
 
     while (0 != (code_point = ZCB_Nip_One(source))) {
         if (code_point == '\\') {
-            u32_t next_code_point = ZCB_Nip_One(source);
-            if (next_code_point == ':') {
+            uint32_t next_code_point = ZCB_Nip_One(source);
+            if (   next_code_point == ':'
+                || next_code_point == '"'
+                || next_code_point == '\\'
+            ) {
                 CB_Cat_Char(target, next_code_point);
             }
             else {
@@ -903,20 +890,14 @@ QParser_expand_leaf(QueryParser *self, Query *query)
     LeafQuery     *leaf_query  = (LeafQuery*)query;
     Schema        *schema      = self->schema; 
     ZombieCharBuf *source_text = ZCB_BLANK();
-    CharBuf       *unescaped   = NULL;
     bool_t         is_phrase   = false;
-    VArray        *fields;
-    VArray        *queries;
-    Query         *retval;
-    u32_t          i, max;
 
-    /* Determine whether we can actually process the input. */
+    // Determine whether we can actually process the input. 
     if (!Query_Is_A(query, LEAFQUERY)) return NULL;
     if (!CB_Get_Size(LeafQuery_Get_Text(leaf_query))) return NULL;
-    else ZCB_Assign(source_text, LeafQuery_Get_Text(leaf_query));
-    unescaped = ZCB_Clone(source_text);
+    ZCB_Assign(source_text, LeafQuery_Get_Text(leaf_query));
 
-    /* If quoted, always generate PhraseQuery. */
+    // If quoted, always generate PhraseQuery. 
     ZCB_Trim(source_text);
     if (ZCB_Code_Point_At(source_text, 0) == '"') {
         is_phrase = true;
@@ -928,7 +909,8 @@ QParser_expand_leaf(QueryParser *self, Query *query)
         }
     }
 
-    /* Either use LeafQuery's field or default to Parser's list. */
+    // Either use LeafQuery's field or default to Parser's list. 
+    VArray *fields;
     if (LeafQuery_Get_Field(leaf_query)) {
         fields = VA_new(1);
         VA_Push(fields, INCREF(LeafQuery_Get_Field(leaf_query)));
@@ -937,37 +919,36 @@ QParser_expand_leaf(QueryParser *self, Query *query)
         fields = (VArray*)INCREF(self->fields);
     }
 
-    queries = VA_new(VA_Get_Size(fields));
-    for (i = 0, max = VA_Get_Size(fields); i < max; i++) {
+    CharBuf *unescaped = CB_new(ZCB_Get_Size(source_text));
+    VArray  *queries   = VA_new(VA_Get_Size(fields));
+    for (uint32_t i = 0, max = VA_Get_Size(fields); i < max; i++) {
         CharBuf   *field    = (CharBuf*)VA_Fetch(fields, i);
-        FieldType *type     = Schema_Fetch_Type(schema, field);
         Analyzer  *analyzer = self->analyzer 
                             ? self->analyzer 
                             : Schema_Fetch_Analyzer(schema, field);
 
-        if (!analyzer || (type && !FType_Is_A(type, FULLTEXTTYPE))) {
+        if (!analyzer) {
             VA_Push(queries,
                 (Obj*)QParser_Make_Term_Query(self, field, 
                     (Obj*)source_text));
         }
         else {
-            /* Extract token texts. */
+            // Extract token texts. 
             CharBuf *split_source 
                 = S_unescape(self, (CharBuf*)source_text, unescaped);
             VArray *maybe_texts = Analyzer_Split(analyzer, split_source);
-            u32_t num_maybe_texts = VA_Get_Size(maybe_texts);
+            uint32_t num_maybe_texts = VA_Get_Size(maybe_texts);
             VArray *token_texts = VA_new(num_maybe_texts);
-            u32_t j;
 
-            /* Filter out zero-length token texts. */
-            for (j = 0; j < num_maybe_texts; j++) {
+            // Filter out zero-length token texts. 
+            for (uint32_t j = 0; j < num_maybe_texts; j++) {
                 CharBuf *token_text = (CharBuf*)VA_Fetch(maybe_texts, j);
                 if (CB_Get_Size(token_text)) {
                     VA_Push(token_texts, INCREF(token_text));
                 }
             }
 
-            /* Add either a TermQuery or a PhraseQuery. */
+            // Add either a TermQuery or a PhraseQuery. 
             if (is_phrase || VA_Get_Size(token_texts) > 1) {
                 VA_Push(queries, (Obj*)
                     QParser_Make_Phrase_Query(self, field, token_texts));
@@ -982,8 +963,9 @@ QParser_expand_leaf(QueryParser *self, Query *query)
         }
     }
 
+    Query *retval;
     if (VA_Get_Size(queries) == 0) {
-        retval = NULL;
+        retval = (Query*)NoMatchQuery_new();
     }
     else if (VA_Get_Size(queries) == 1) {
         retval = (Query*)INCREF(VA_Fetch(queries, 0));
@@ -992,7 +974,7 @@ QParser_expand_leaf(QueryParser *self, Query *query)
         retval = QParser_Make_OR_Query(self, queries);
     }
 
-    /* Clean up. */
+    // Clean up. 
     DECREF(unescaped);
     DECREF(queries);
     DECREF(fields);
@@ -1019,15 +1001,15 @@ S_extract_something(QueryParser *self, const CharBuf *query_string,
         size_t   after_match  = retval_end - end_match;
         CharBuf *new_retval   = CB_new(qstring_size);
 
-        /* Store inner text. */
+        // Store inner text. 
         CB_catf(label, "%u32", self->label_inc++);
         Hash_Store(extractions, (Obj*)label, 
             (Obj*)CB_new_from_utf8(begin_match, len));
 
-        /* Splice the label into the query string. */
+        // Splice the label into the query string. 
         CB_Cat_Str(new_retval, retval_buf, before_match);
         CB_Cat(new_retval, label);
-        CB_Cat_Str(new_retval, " ", 1); /* Extra space for safety. */
+        CB_Cat_Str(new_retval, " ", 1); // Extra space for safety. 
         CB_Cat_Str(new_retval, end_match, after_match);
         DECREF(retval);
         retval = new_retval;
@@ -1049,15 +1031,22 @@ static bool_t
 S_match_phrase(CharBuf *input, char**begin_match, char **end_match)
 {
     ZombieCharBuf *iterator = ZCB_WRAP(input);
-    u32_t code_point;
+    uint32_t code_point;
 
     while (0 != (code_point = ZCB_Code_Point_At(iterator, 0))) {
+        if (code_point == '\\') {
+            ZCB_Nip(iterator, 2);
+            continue;
+        }
         if (code_point == '"') {
             *begin_match = (char*)ZCB_Get_Ptr8(iterator); 
             *end_match   = *begin_match + ZCB_Get_Size(iterator);
             ZCB_Nip_One(iterator);
             while (0 != (code_point = ZCB_Nip_One(iterator))) {
-                if (code_point == '\\') { continue; }
+                if (code_point == '\\') { 
+                    ZCB_Nip_One(iterator);
+                    continue; 
+                }
                 else if (code_point == '"') {
                     *end_match = (char*)ZCB_Get_Ptr8(iterator);
                     return true;
@@ -1082,7 +1071,7 @@ static bool_t
 S_match_bool_group(CharBuf *input, char**begin_match, char **end_match)
 {
     ZombieCharBuf *iterator = ZCB_WRAP(input);
-    u32_t code_point;
+    uint32_t code_point;
 
     while (0 != (code_point = ZCB_Code_Point_At(iterator, 0))) {
         if (code_point == '(') {
@@ -1152,14 +1141,14 @@ QParser_make_req_opt_query(QueryParser *self, Query *required_query,
 /********************************************************************/
 
 ParserClause*
-ParserClause_new(Query *query, u32_t occur)
+ParserClause_new(Query *query, uint32_t occur)
 {
     ParserClause *self = (ParserClause*)VTable_Make_Obj(PARSERCLAUSE);
     return ParserClause_init(self, query, occur);
 }
 
 ParserClause*
-ParserClause_init(ParserClause *self, Query *query, u32_t occur)
+ParserClause_init(ParserClause *self, Query *query, uint32_t occur)
 {
     self->query = (Query*)INCREF(query);
     self->occur = occur;
@@ -1176,14 +1165,14 @@ ParserClause_destroy(ParserClause *self)
 /********************************************************************/
 
 ParserToken*
-ParserToken_new(u32_t type, const char *text, size_t len)
+ParserToken_new(uint32_t type, const char *text, size_t len)
 {
     ParserToken *self = (ParserToken*)VTable_Make_Obj(PARSERTOKEN);
     return ParserToken_init(self, type, text, len);
 }
 
 ParserToken*
-ParserToken_init(ParserToken *self, u32_t type, const char *text, size_t len)
+ParserToken_init(ParserToken *self, uint32_t type, const char *text, size_t len)
 {
     self->type = type;
     self->text = text ? CB_new_from_utf8(text, len) : NULL;
