@@ -18,16 +18,16 @@ test_Dump_Load_and_Equals(TestBatch *batch)
     Obj       *dump          = (Obj*)LeafQuery_Dump(query);
     LeafQuery *clone         = (LeafQuery*)LeafQuery_Load(term_differs, dump);
 
-    ASSERT_FALSE(batch, LeafQuery_Equals(query, (Obj*)field_differs),
+    TEST_FALSE(batch, LeafQuery_Equals(query, (Obj*)field_differs),
         "Equals() false with different field");
-    ASSERT_FALSE(batch, LeafQuery_Equals(query, (Obj*)null_field),
+    TEST_FALSE(batch, LeafQuery_Equals(query, (Obj*)null_field),
         "Equals() false with null field");
-    ASSERT_FALSE(batch, LeafQuery_Equals(query, (Obj*)term_differs),
+    TEST_FALSE(batch, LeafQuery_Equals(query, (Obj*)term_differs),
         "Equals() false with different term");
     LeafQuery_Set_Boost(boost_differs, 0.5);
-    ASSERT_FALSE(batch, LeafQuery_Equals(query, (Obj*)boost_differs),
+    TEST_FALSE(batch, LeafQuery_Equals(query, (Obj*)boost_differs),
         "Equals() false with different boost");
-    ASSERT_TRUE(batch, LeafQuery_Equals(query, (Obj*)clone), 
+    TEST_TRUE(batch, LeafQuery_Equals(query, (Obj*)clone), 
         "Dump => Load round trip");
 
     DECREF(query);
@@ -42,13 +42,13 @@ test_Dump_Load_and_Equals(TestBatch *batch)
 void
 TestLeafQuery_run_tests()
 {
-    TestBatch *batch = Test_new_batch("TestLeafQuery", 5, NULL);
-    PLAN(batch);
+    TestBatch *batch = TestBatch_new(5);
+    TestBatch_Plan(batch);
     test_Dump_Load_and_Equals(batch);
-    batch->destroy(batch);
+    DECREF(batch);
 }
 
-/* Copyright 2005-2009 Marvin Humphrey
+/* Copyright 2005-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
