@@ -1,3 +1,4 @@
+#define C_KINO_TESTREQOPTQUERY
 #include "KinoSearch/Util/ToolSet.h"
 #include <math.h>
 
@@ -20,14 +21,14 @@ test_Dump_Load_and_Equals(TestBatch *batch)
     RequiredOptionalQuery *clone 
         = (RequiredOptionalQuery*)Obj_Load(dump, dump);
 
-    ASSERT_FALSE(batch, ReqOptQuery_Equals(query, (Obj*)kids_differ), 
+    TEST_FALSE(batch, ReqOptQuery_Equals(query, (Obj*)kids_differ), 
         "Different kids spoil Equals");
-    ASSERT_TRUE(batch, ReqOptQuery_Equals(query, (Obj*)boost_differs), 
+    TEST_TRUE(batch, ReqOptQuery_Equals(query, (Obj*)boost_differs), 
         "Equals with identical boosts");
     ReqOptQuery_Set_Boost(boost_differs, 1.5);
-    ASSERT_FALSE(batch, ReqOptQuery_Equals(query, (Obj*)boost_differs), 
+    TEST_FALSE(batch, ReqOptQuery_Equals(query, (Obj*)boost_differs), 
         "Different boost spoils Equals");
-    ASSERT_TRUE(batch, ReqOptQuery_Equals(query, (Obj*)clone), 
+    TEST_TRUE(batch, ReqOptQuery_Equals(query, (Obj*)clone), 
         "Dump => Load round trip");
 
     DECREF(a_leaf);
@@ -43,13 +44,13 @@ test_Dump_Load_and_Equals(TestBatch *batch)
 void
 TestReqOptQuery_run_tests()
 {
-    TestBatch *batch = Test_new_batch("TestReqOptQuery", 4, NULL);
-    PLAN(batch);
+    TestBatch *batch = TestBatch_new(4);
+    TestBatch_Plan(batch);
     test_Dump_Load_and_Equals(batch);
-    batch->destroy(batch);
+    DECREF(batch);
 }
 
-/* Copyright 2005-2009 Marvin Humphrey
+/* Copyright 2005-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
