@@ -5,7 +5,7 @@
 extern "C" {
 #endif
 
-/* ToolSet groups together several commonly used header files, so that only
+/** ToolSet groups together several commonly used header files, so that only
  * one pound-include directive is needed for them.
  *
  * It should only be used internally, and only included in C files rather than
@@ -28,7 +28,6 @@ extern "C" {
 #include "KinoSearch/Object/Hash.h"
 #include "KinoSearch/Object/I32Array.h"
 #include "KinoSearch/Object/Num.h"
-#include "KinoSearch/Object/Undefined.h"
 #include "KinoSearch/Object/VArray.h"
 #include "KinoSearch/Object/VTable.h"
 #include "KinoSearch/Util/NumberUtils.h"
@@ -39,7 +38,7 @@ extern "C" {
 }
 #endif
 
-#endif /* H_KINO_TOOLSET */
+#endif // H_KINO_TOOLSET 
 
 /* Copyright 2006-2010 Marvin Humphrey
  *
