@@ -1,3 +1,4 @@
+package KinoSearch::Analysis::Stemmer;
 use KinoSearch;
 
 1;
@@ -50,7 +51,7 @@ my $constructor = <<'END_CONSTRUCTOR';
     my $stemmer = KinoSearch::Analysis::Stemmer->new( language => 'es' );
 END_CONSTRUCTOR
 
-Boilerplater::Binding::Perl::Class->register(
+Clownfish::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Analysis::Stemmer",
     bind_constructors => ["new"],
@@ -63,7 +64,7 @@ Boilerplater::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2009 Marvin Humphrey
+Copyright 2005-2010 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself
