@@ -1,3 +1,4 @@
+package KinoSearch::Search::PolySearcher;
 use KinoSearch;
 
 1;
@@ -16,32 +17,40 @@ my $synopsis = <<'END_SYNOPSIS';
         );
     }
     my $poly_searcher = KinoSearch::Search::PolySearcher->new(
-        schema      => $schema,
-        searchables => \@searchers,
+        schema    => $schema,
+        searchers => \@searchers,
     );
     my $hits = $poly_searcher->hits( query => $query );
 END_SYNOPSIS
 
 my $constructor = <<'END_CONSTRUCTOR';
     my $poly_searcher = KinoSearch::Search::PolySearcher->new(
-        schema      => $schema,
-        searchables => \@searchers,
+        schema    => $schema,
+        searchers => \@searchers,
     );
 END_CONSTRUCTOR
 
-Boilerplater::Binding::Perl::Class->register(
+Clownfish::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Search::PolySearcher",
     bind_constructors => ["new"],
     make_pod          => {
         synopsis    => $synopsis,
         constructor => { sample => $constructor },
+        methods     => [
+            qw( hits
+                doc_max
+                doc_freq
+                fetch_doc
+                get_schema
+                )
+        ],
     }
 );
 
 __COPYRIGHT__
 
-Copyright 2005-2009 Marvin Humphrey
+Copyright 2005-2010 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
